@@ -3,7 +3,7 @@
 extern crate pathfinding;
 extern crate test;
 
-use pathfinding::{astar, bfs, dfs, dijkstra, fringe, idastar};
+use pathfinding::prelude::{astar, bfs, dfs, dijkstra, fringe, idastar};
 use test::Bencher;
 
 #[derive(Clone, Debug, Eq, Hash, Ord, PartialEq, PartialOrd)]
@@ -14,7 +14,7 @@ struct Pt {
 
 impl Pt {
     fn new(x: u16, y: u16) -> Pt {
-        Pt { x: x, y: y }
+        Pt { x, y }
     }
 
     #[inline]
