@@ -5,7 +5,7 @@ extern crate rand;
 
 use itertools::Itertools;
 use pathfinding::grid::Grid;
-use rand::{Rng, StdRng};
+use rand::prelude::*;
 
 #[test]
 fn empty_grid() {
@@ -155,22 +155,22 @@ fn fill_clear_invert_empty_full() {
 
 #[test]
 fn iterators() {
-    let mut rng = StdRng::new().unwrap();
+    let mut rng = StdRng::from_entropy();
     for _ in 0..100 {
         let mut g = Grid::new(10, 20);
-        if rng.gen_weighted_bool(2) {
+        if rng.gen_bool(0.5) {
             g.fill();
         }
         for _ in 0..1000 {
             let x = rng.next_u64() as usize % g.width;
             let y = rng.next_u64() as usize % g.height;
-            if rng.gen_weighted_bool(2) {
+            if rng.gen_bool(0.5) {
                 g.add_vertex((x, y));
             } else {
                 g.remove_vertex(&(x, y));
             }
         }
-        if rng.gen_weighted_bool(5) {
+        if rng.gen_bool(0.2) {
             g.invert();
         }
         let mut ns1 = g.iter().collect_vec();
